Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(45)

Unified Diff: tools/dom/src/CssRectangle.dart

Issue 25808002: Move Rectangle and Point into dart:math. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/dom/src/CssRectangle.dart
diff --git a/tools/dom/src/CssRectangle.dart b/tools/dom/src/CssRectangle.dart
index 6808927349820367614c1c6218f425a4e0daf474..fe1c56235b399a043891d963775ca4291b72edd4 100644
--- a/tools/dom/src/CssRectangle.dart
+++ b/tools/dom/src/CssRectangle.dart
@@ -148,18 +148,19 @@ class _MarginCssRect extends CssRect {
/**
* A class for representing CSS dimensions.
*
* In contrast to the more general purpose [Rect] class, this class's values are
* mutable, so one can change the height of an element programmatically.
*
* _Important_ _note_: use of these methods will perform CSS calculations that
* can trigger a browser reflow. Therefore, use of these properties _during_ an
* animation frame is discouraged. See also:
* [Browser Reflow](https://developers.google.com/speed/articles/reflow)
*/
-abstract class CssRect extends RectBase implements Rect {
+abstract class CssRect extends MutableRectangle<num> implements Rectangle<num> {
Element _element;
- CssRect(this._element);
+ CssRect(this._element) : super(0, 0, 0, 0);
num get left;

Powered by Google App Engine
@@ -148,18 +148,19 @@ class _MarginCssRect extends CssRect {
* A class for representing CSS dimensions.
*
- * In contrast to the more general purpose [Rect] class, this class's values are
- * mutable, so one can change the height of an element programmatically.
+ * In contrast to the more general purpose [Rectangle] class, this class's
+ * values are mutable, so one can change the height of an element
+ * programmatically.
*
* _Important_ _note_: use of these methods will perform CSS calculations that
This is Rietveld 408576698